Anomaly detectors — skchange

Skip to main content
`Ctrl`+`K`

# Anomaly detectors

## Base

`BaseSegmentAnomalyDetector`() | Base class for segment anomaly detectors.

## Segment anomaly detectors

`CAPA`([segment_saving, point_saving, ...]) | The collective and point anomaly (CAPA) detection algorithm.
`CircularBinarySegmentation`([anomaly_score, ...]) | Circular binary segmentation algorithm for multiple segment anomaly detection.
`StatThresholdAnomaliser`(change_detector, ...) | Anomaly detection based on thresholding the values of segment statistics.

## Segment anomaly detectors with variable identification

`MVCAPA`([segment_saving, point_saving, ...]) | Subset multivariate collective and point anomaly detection.